@@ -1,12 +1,12 @@
 article_letterpaper_10pt_singlecolumn = {"textwidth": 4.77,
-                                         "linewidth": 4.77,
+                                         "columnwidth": 4.77,
                                          "fontsize": 10}
 """
 Defaults for ``\\documentclass[letterpaper, 10pt]{article}``
 """
 
 article_letterpaper_10pt_doublecolumn = {"textwidth": 6.49,
-                                         "linewidth": 3.17,
+                                         "columnwidth": 3.17,
                                          "fontsize": 10}
 """
 Defaults for ``\\documentclass[letterpaper, 10pt, twocolumn]{article}``
